clarity: Create remoteDriver and login to Clarity

Description Methods

Description

An R6 Class to manage the Clarity automation

Methods

Public methods


Method new()

Usage
clarity$new(
  ini_path = file.path("inst", "auth", "Clarity.ini"),
  clarity_url = "https://cohhio.clarityhs.com/",
  ...
)
Arguments
clarity_url

(character) the full URL to the Clarity instance to log in to


Method debug_int()

Usage
clarity$debug_int()

Method get_hud_export()

Usage
clarity$get_hud_export(
  end_date = Sys.Date(),
  schedule = TRUE,
  browser_dl_folder = "C:\\\\Users\\\\Administrator\\\\Downloads",
  extract_path = "~/R/Contributor_Repos/COHHIO/Rm_data/data",
  delete_archive = TRUE
)

Method clone()

The objects of this class are cloneable with this method.

Usage
clarity$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


COHHIO/clarity.automation documentation built on Dec. 17, 2021, 1 p.m.