hud_export_extract: Extract a previously downloaded HUD Export archive

Description Usage Arguments Value

View source: R/rsel.R

Description

Extract a previously downloaded HUD Export archive

Usage

1
2
3
4
5
6
7
hud_export_extract(
  browser_dl_folder = "~/../Downloads",
  extract_path = "data",
  delete_archive = TRUE,
  moment = Sys.Date(),
  wait = lubridate::minutes(2)
)

Arguments

browser_dl_folder

(character) path to the browser's download folder

extract_path

(character) path to the folder where the archive is to be extracted

delete_archive

(logical) Delete the archive after extracting?

moment

(POSIXct/Date) The time point which the archive creation time should be greater than to ensure it's recent.

wait

(Duration) to wait for the file to appear in the download directory. Relevant when using browser automation.

Value

(logical) as to whether the extraction was successful


COHHIO/clarity.automation documentation built on Dec. 17, 2021, 1 p.m.