An R6 Class to manage the Clarity automation
new()clarity$new(
ini_path = file.path("inst", "auth", "Clarity.ini"),
clarity_url = "https://cohhio.clarityhs.com/",
...
)clarity_url(character) the full URL to the Clarity instance to log in to
debug_int()clarity$debug_int()
get_hud_export()clarity$get_hud_export( end_date = Sys.Date(), schedule = TRUE, browser_dl_folder = "C:\\\\Users\\\\Administrator\\\\Downloads", extract_path = "~/R/Contributor_Repos/COHHIO/Rm_data/data", delete_archive = TRUE )
clone()The objects of this class are cloneable with this method.
clarity$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.